import { BaseObject, Rectangle } from '@/pdf-element-marker'
import LabeledRect from '@/fabric/labeled.rect'
import { reactive, toRaw } from 'vue'
import useVModelEmit from '@/composables/useVModelEmit'

export default () => {
    const vModelEmit = useVModelEmit()

    const deleteObject = (item: BaseObject) => {
        const canvas = item.canvas
        canvas?.remove(toRaw(item))
        vModelEmit(canvas)
    }
    const cloneObject = (item: BaseObject) => {
        // Not doing a built-in fabric clone as it's not working
        const rect = new LabeledRect(reactive({
            left: item.left + 20,
            top: item.top + 20,
            originX: item.originX,
            originY: item.originY,
            width: item.width,
            height: item.height,
            stroke: item.stroke,
            strokeWidth: item.strokeWidth,
            strokeUniform: item.strokeUniform,
            cornerSize: item.cornerSize,
            borderColor: 'rgba(0, 0, 255, 0.5)',
            cornerColor: 'rgba(0, 0, 255, 0.5)',
            label: `${item.label} (copy)`,
            fill: item.fill,
            transparentCorners: item.transparentCorners,
        })) as Rectangle

        rect.setControlVisible('mtr', item.isRotatable || false)
        toRaw(item.canvas)?.add(rect)
        vModelEmit(item.canvas)
        item.canvas?.setActiveObject(rect)
    }

    return {
        deleteObject,
        cloneObject,
    }
}
